@@ -22,8 +22,8 @@ class VideoTransformTrack(MediaStreamTrack):
 
     async def recv(self):
         frame = await self.track.recv()
-        await self.onframe(self.gsdbs, self.source, frame)
-        return frame
+        self.onframe(self.gsdbs, self.source, frame)
+
 
 
 class GSPeerConnectionWatcher:
